@@ -76,11 +76,6 @@ def print_error(error_string):  # RED
     logger.error("{}".format(error_string))
 
 
-def print_info(info_string):  # GREEN
-    print("\033[33m{}\033[0m".format(info_string))
-    logger.info("{}".format(info_string))
-
-
 def load_json(path, base_path=None):
     """Load JSON from a file.
 
@@ -111,8 +106,8 @@ def add_criterion(topic, index, criterion, value=None):
 
     # TODO: Add extra parameter to the criterion creation for these criterion types
     if criterion == "ATDateRangeCriterion":
-        crit.setStart(u"2019/02/20 13:55:00 GMT-3")
-        crit.setEnd(u"2019/02/22 13:55:00 GMT-3")
+        crit.setStart("2019/02/20 13:55:00 GMT-3")
+        crit.setEnd("2019/02/22 13:55:00 GMT-3")
     elif criterion == "ATSortCriterion":
         crit.setReversed(True)
     elif criterion == "ATBooleanCriterion":
@@ -189,7 +184,7 @@ def create_object(path, is_folder=False):
     else:
         parent = create_object(path_parent, is_folder=True)
 
-    logger.info('Creating "{0}"'.format(path))
+    logger.info(f"{path} - create")
 
     obj = api.content.create(
         container=parent, type="Folder" if is_folder else "Document", id=obj_id
@@ -516,11 +511,10 @@ def create_item_runner(  # noqa
                     notify(ObjectCreatedEvent(obj))
 
                 obj = add(container, obj, rename=not bool(id_))
-                obj_path = "/".join(obj.getPhysicalPath())
                 for image_fieldname in image_fieldnames_added:
-                    print_info(
-                        "Generating image scales for {} field in {}".format(
-                            image_fieldname, obj_path
+                    logger.debug(
+                        "{} - generating image scales for {} field".format(
+                            "/".join(obj.getPhysicalPath()), image_fieldname
                         )
                     )
                     plone_scale_generate_on_save(obj, request, image_fieldname)
@@ -564,9 +558,9 @@ def create_item_runner(  # noqa
             path = "/".join(obj.getPhysicalPath())
 
             if create_object:
-                logger.info("{0}: created".format(path))
+                logger.info(f"{path} - created")
             else:
-                logger.info("{0}: edited".format(path))
+                logger.info(f"{path} - edited")
 
             # CONSTRAIN TYPES
             locally_allowed_types = opts.get("locally_allowed_types", False)
@@ -580,7 +574,7 @@ def create_item_runner(  # noqa
                     if locally_allowed_types:
                         be.setLocallyAllowedTypes = locally_allowed_types
                         logger.warn(
-                            "{0}: locally_allowed_types {1}".format(
+                            "{0} - locally_allowed_types {1}".format(
                                 path, locally_allowed_types
                             )
                         )  # noqa
@@ -589,7 +583,7 @@ def create_item_runner(  # noqa
                             immediately_allowed_types  # noqa
                         )
                         logger.warn(
-                            "{0}: immediately_allowed_types {1}".format(
+                            "{0} - immediately_allowed_types {1}".format(
                                 path, immediately_allowed_types
                             )
                         )  # noqa
@@ -801,7 +795,7 @@ def content_creator_from_folder(
         # structure
         if file_ == "content.json":
             has_content_json = True
-            print_info("content.json file found, creating content")
+            logger.info("content.json file found, creating content")
             content_structure = load_json(os.path.join(folder, "content.json"))
             create_item_runner(
                 api.portal.get(),
@@ -815,7 +809,7 @@ def content_creator_from_folder(
             )
             continue
         elif file_ == "siteroot.json":
-            print_info("Site root info found, applying changes")
+            logger.info("Site root info found, applying changes")
             root_info = load_json(os.path.join(folder, "siteroot.json"))
             modify_siteroot(root_info)
             continue
@@ -857,12 +851,12 @@ def content_creator_from_folder(
 
     # After creation, we refresh all the content created to update resolveuids
     if len(files) > 0:
-        print_info("Refreshing content serialization after creation...")
+        logger.info("Refreshing content serialization after creation...")
     for file_ in files:
         filepath = os.path.join(folder, file_)
         refresh_objects_created_by_file(filepath, file_)
     if has_content_json:
-        print_info(
+        logger.info(
             "Refreshing structured (content.json) content serialization after creation..."
         )
         refresh_objects_created_by_structure(api.portal.get(), content_structure)
